Class: PlatformRest::ApplicationJobLogs
- Inherits:
-
Object
- Object
- PlatformRest::ApplicationJobLogs
- Defined in:
- lib/platform_rest/application_job_logs.rb
Overview
Class containing all the actions for the Application Job Logs Resource
Instance Method Summary collapse
-
#get(params = {}) ⇒ Object
Returns the job logs for an application.
-
#initialize(client) ⇒ ApplicationJobLogs
constructor
A new instance of ApplicationJobLogs.
Constructor Details
#initialize(client) ⇒ ApplicationJobLogs
Returns a new instance of ApplicationJobLogs.
30 31 32 |
# File 'lib/platform_rest/application_job_logs.rb', line 30 def initialize(client) @client = client end |
Instance Method Details
#get(params = {}) ⇒ Object
Returns the job logs for an application
Authentication: The client must be configured with a valid api access token to call this action. The token must include at least one of the following scopes: all.Application, all.Application.bounded, all.Application.read, all.Organization, all.Organization.bounded, all.Organization.read, all.User, all.User.bounded, all.User.read, applicationJobLogs.*, or applicationJobLogs.get.
Parameters:
- string applicationId - ID associated with the application
- string sortField - Field to sort the results by. Accepted values are: name, status, resourceType, runQueuedAt, runStartedAt, runCompletedAt
- string sortDirection - Direction to sort the results by. Accepted values are: asc, desc
- string page - Which page of results to return
- string perPage - How many items to return per page
- hash query - Filter application job logs by a query. (https://api.losant.com/#/definitions/advancedApplicationJobLogQuery)
- string losantdomain - Domain scope of request (rarely needed)
- boolean _actions - Return resource actions in response
- boolean _links - Return resource link in response
- boolean _embedded - Return embedded resources in response
Responses:
- 200 - Collection of application job logs (https://api.losant.com/#/definitions/applicationJobLogs)
Errors:
- 400 - Error if malformed request (https://api.losant.com/#/definitions/error)
- 404 - Error if application was not found (https://api.losant.com/#/definitions/error)
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/platform_rest/application_job_logs.rb', line 60 def get(params = {}) params = Utils.symbolize_hash_keys(params) query_params = { _actions: false, _links: true, _embedded: true } headers = {} body = nil raise ArgumentError.new("applicationId is required") unless params.has_key?(:applicationId) query_params[:sortField] = params[:sortField] if params.has_key?(:sortField) query_params[:sortDirection] = params[:sortDirection] if params.has_key?(:sortDirection) query_params[:page] = params[:page] if params.has_key?(:page) query_params[:perPage] = params[:perPage] if params.has_key?(:perPage) query_params[:query] = params[:query] if params.has_key?(:query) query_params[:query] = JSON.dump(query_params[:query]) if query_params.has_key?(:query) headers[:losantdomain] = params[:losantdomain] if params.has_key?(:losantdomain) query_params[:_actions] = params[:_actions] if params.has_key?(:_actions) query_params[:_links] = params[:_links] if params.has_key?(:_links) query_params[:_embedded] = params[:_embedded] if params.has_key?(:_embedded) path = "/applications/#{params[:applicationId]}/jobLogs" @client.request( method: :get, path: path, query: query_params, headers: headers, body: body) end |